@@ -1,7 +1,7 @@
 #' Check Array
 #'
 #' @description
-#' Checks if is a array using
+#' Checks if is an array using
 #'
 #' `is.array(x)`
 #'
@@ -17,7 +17,7 @@
 #' @export
 chk_array <- function(x, x_name = NULL) {
   if (vld_array(x)) {
-    return(invisible())
+    return(invisible(x))
   }
   if (is.null(x_name)) x_name <- deparse_backtick_chk(substitute(x))
   abort_chk(x_name, " must be an array", x = x)
@@ -26,8 +26,10 @@ chk_array <- function(x, x_name = NULL) {
 #' @describeIn chk_array Validate Array
 #'
 #' @examples
+#'
 #' # vld_array
 #' vld_array(1)
 #' vld_array(array(1))
 #' @export
 vld_array <- function(x) is.array(x)
+
