@@ -18,7 +18,7 @@
 #' @export
 chk_character_or_factor <- function(x, x_name = NULL) {
   if (vld_character_or_factor(x)) {
-    return(invisible())
+    return(invisible(x))
   }
   if (is.null(x_name)) x_name <- deparse_backtick_chk((substitute(x)))
   abort_chk(x_name, " must be character or factor", x = x)
@@ -37,3 +37,4 @@ chk_character_or_factor <- function(x, x_name = NULL) {
 #' vld_character_or_factor(factor("text"))
 #' @export
 vld_character_or_factor <- function(x) is.character(x) || is.factor(x)
+
