@@ -20,7 +20,7 @@
 chk_equivalent <- function(x, y, tolerance = sqrt(.Machine$double.eps),
                            x_name = NULL) {
   if (vld_equivalent(x, y, tolerance = tolerance)) {
-    return(invisible())
+    return(invisible(x))
   }
   if (is.null(x_name)) x_name <- deparse_backtick_chk(substitute(x))
   y_name <- as_label(y)
