@@ -19,15 +19,14 @@
 #' @export
 chk_ext <- function(x, ext, x_name = NULL) {
   if (vld_ext(x, ext)) {
-    return(invisible())
+    return(invisible(x))
   }
   if (is.null(x_name)) x_name <- deparse_backtick_chk(substitute(x))
   chk_string(x, x_name = x_name)
   abort_chk(
     x_name, " must have extension ", cc(ext, " or "), " (not '",
     tools::file_ext(x), "')",
-    x = x, ext = ext
-  )
+    x = x, ext = ext)
 }
 
 #' @describeIn chk_ext Validate File Extension
@@ -38,3 +37,4 @@ chk_ext <- function(x, ext, x_name = NULL) {
 #' vld_ext(toupper("oeu.pdf"), "PDF")
 #' @export
 vld_ext <- function(x, ext) vld_string(x) && vld_subset(tools::file_ext(x), ext)
+
