@@ -17,7 +17,7 @@
 #' @export
 chk_false <- function(x, x_name = NULL) {
   if (vld_false(x)) {
-    return(invisible())
+    return(invisible(x))
   }
   if (is.null(x_name)) x_name <- deparse_backtick_chk(substitute(x))
   abort_chk(x_name, " must be FALSE", x = x)
@@ -34,3 +34,4 @@ chk_false <- function(x, x_name = NULL) {
 #' vld_false(c(FALSE, FALSE))
 #' @export
 vld_false <- function(x) is.logical(x) && length(x) == 1L && !anyNA(x) && !x
+
