@@ -16,7 +16,7 @@
 #' @export
 chk_file <- function(x, x_name = NULL) {
   if (vld_file(x)) {
-    return(invisible())
+    return(invisible(x))
   }
   if (is.null(x_name)) x_name <- deparse_backtick_chk(substitute(x))
   chk_string(x, x_name = x_name)
@@ -33,3 +33,5 @@ chk_file <- function(x, x_name = NULL) {
 #' vld_file(tempfile())
 #' @export
 vld_file <- function(x) vld_string(x) && file.exists(x) && !dir.exists(x)
+
+
