@@ -21,7 +21,7 @@
 #' @export
 chk_flag <- function(x, x_name = NULL) {
   if (vld_flag(x)) {
-    return(invisible())
+    return(invisible(x))
   }
   if (is.null(x_name)) x_name <- deparse_backtick_chk(substitute(x))
   abort_chk(x_name, " must be a flag (TRUE or FALSE)", x = x)
@@ -35,3 +35,4 @@ chk_flag <- function(x, x_name = NULL) {
 #' vld_flag(1)
 #' @export
 vld_flag <- function(x) is.logical(x) && length(x) == 1L && !anyNA(x)
+
