@@ -16,10 +16,11 @@
 #' @export
 chk_is <- function(x, class, x_name = NULL) {
   if (vld_is(x, class)) {
-    return(invisible())
+    return(invisible(x))
   }
   if (is.null(x_name)) x_name <- deparse_backtick_chk(substitute(x))
   abort_chk(x_name, " must inherit from class '", class, "'", x = x, class = class)
+
 }
 
 #' @describeIn chk_is Validate Inherits from Class
@@ -33,3 +34,4 @@ chk_is <- function(x, class, x_name = NULL) {
 vld_is <- function(x, class) {
   inherits(x, class)
 }
+
