@@ -18,14 +18,13 @@
 #' @export
 chk_join <- function(x, y, by, x_name = NULL) {
   if (vld_join(x, y, by)) {
-    return(invisible())
+    return(invisible(x))
   }
   if (is.null(x_name)) x_name <- deparse_backtick_chk(substitute(x))
   y_name <- as_label(y)
   abort_chk("All rows in ", x_name, " must match at least one in: ",
-    y_name,
-    x = x, y = y, by = by
-  )
+            y_name,
+            x = x, y = y, by = by)
 }
 
 #' @describeIn chk_join Validate Join
@@ -45,3 +44,4 @@ vld_join <- function(x, y, by) {
     ))
   )
 }
+
