@@ -17,7 +17,7 @@
 #' @export
 chk_list <- function(x, x_name = NULL) {
   if (vld_list(x)) {
-    return(invisible())
+    return(invisible(x))
   }
   if (is.null(x_name)) x_name <- deparse_backtick_chk(substitute(x))
   abort_chk(x_name, " must be a list", x = x)
@@ -34,3 +34,4 @@ chk_list <- function(x, x_name = NULL) {
 #' vld_list(NULL)
 #' @export
 vld_list <- function(x) is.list(x)
+
