@@ -17,7 +17,7 @@
 #' @export
 chk_named <- function(x, x_name = NULL) {
   if (vld_named(x)) {
-    return(invisible())
+    return(invisible(x))
   }
   if (is.null(x_name)) x_name <- deparse_backtick_chk((substitute(x)))
   abort_chk(x_name, " must be named", x = x)
@@ -35,3 +35,4 @@ chk_named <- function(x, x_name = NULL) {
 #' vld_named(list(1))
 #' @export
 vld_named <- function(x) !is.null(names(x))
+
