@@ -17,7 +17,7 @@
 #' @export
 chk_not_null <- function(x, x_name = NULL) {
   if (vld_not_null(x)) {
-    return(invisible())
+    return(invisible(x))
   }
   if (is.null(x_name)) x_name <- deparse_backtick_chk(substitute(x))
   abort_chk(x_name, " must not be NULL", x = x)
@@ -31,3 +31,4 @@ chk_not_null <- function(x, x_name = NULL) {
 #' vld_not_null(NULL)
 #' @export
 vld_not_null <- function(x) !is.null(x)
+
