@@ -17,10 +17,11 @@
 #' @export
 chk_not_subset <- function(x, values, x_name = NULL) {
   if (vld_not_subset(x, values)) {
-    return(invisible())
+    return(invisible(x))
   }
   values <- sort(unique(values), na.last = TRUE)
   if (is.null(x_name)) x_name <- deparse_backtick_chk(substitute(x))
+
   if (length(x) == 1L) {
     abort_chk(x_name, " must not match ", cc(unique(c(x, values)), " or "), x = x, values = values)
   }
@@ -36,3 +37,4 @@ chk_not_subset <- function(x, values, x_name = NULL) {
 #' vld_not_subset(11, 1:10)
 #' @export
 vld_not_subset <- function(x, values) !any(x %in% values) || !length(x)
+
