@@ -18,7 +18,7 @@
 #' @export
 chk_scalar <- function(x, x_name = NULL) {
   if (vld_scalar(x)) {
-    return(invisible())
+    return(invisible(x))
   }
   if (is.null(x_name)) x_name <- deparse_backtick_chk(substitute(x))
   abort_chk(x_name, " must be a scalar (length 1)", x = x)
@@ -31,3 +31,4 @@ chk_scalar <- function(x, x_name = NULL) {
 #' vld_scalar(1)
 #' @export
 vld_scalar <- function(x) length(x) == 1L
+
