@@ -17,7 +17,7 @@
 #' @export
 chk_sorted <- function(x, x_name = NULL) {
   if (vld_sorted(x)) {
-    return(invisible())
+    return(invisible(x))
   }
   if (is.null(x_name)) x_name <- deparse_backtick_chk(substitute(x))
   abort_chk(x_name, " must be sorted", x = x)
@@ -31,3 +31,4 @@ chk_sorted <- function(x, x_name = NULL) {
 #' vld_sorted(2:1)
 #' @export
 vld_sorted <- function(x) !is.unsorted(x)
+
