@@ -17,7 +17,7 @@
 #' @export
 chk_subset <- function(x, values, x_name = NULL) {
   if (vld_subset(x, values)) {
-    return(invisible())
+    return(invisible(x))
   }
   values <- sort(unique(values), na.last = TRUE)
   if (is.null(x_name)) x_name <- deparse_backtick_chk(substitute(x))
@@ -36,3 +36,4 @@ chk_subset <- function(x, values, x_name = NULL) {
 #' vld_subset(11, 1:10)
 #' @export
 vld_subset <- function(x, values) all(x %in% values)
+
