@@ -16,7 +16,7 @@
 #' @export
 chk_tz <- function(x, x_name = NULL) {
   if (vld_tz(x)) {
-    return(invisible())
+    return(invisible(x))
   }
   if (is.null(x_name)) x_name <- deparse_backtick_chk(substitute(x))
   abort_chk(x_name, " must be a tz (non-missing scalar character of a recognized timezone)", x = x)
@@ -32,3 +32,4 @@ vld_tz <- function(x) {
   is.character(x) && length(x) == 1L && !anyNA(x) &&
     x %in% OlsonNames()
 }
+
