@@ -21,14 +21,13 @@
 #' @export
 chk_whole_number <- function(x, x_name = NULL) {
   if (vld_whole_number(x)) {
-    return(invisible())
+    return(invisible(x))
   }
   if (is.null(x_name)) x_name <- deparse_backtick_chk(substitute(x))
   abort_chk(
     x_name,
     " must be a whole number (non-missing integer scalar or double equivalent)",
-    x = x
-  )
+    x = x)
 }
 
 #' @describeIn chk_whole_number Validate Whole Number
@@ -41,3 +40,4 @@ vld_whole_number <- function(x) {
   vld_number(x) &&
     (is.integer(x) || vld_true(all.equal(x, trunc(x))))
 }
+
