@@ -18,14 +18,13 @@
 #' @export
 chk_whole_numeric <- function(x, x_name = NULL) {
   if (vld_whole_numeric(x)) {
-    return(invisible())
+    return(invisible(x))
   }
   if (is.null(x_name)) x_name <- deparse_backtick_chk(substitute(x))
   abort_chk(
     x_name,
     " must be a whole numeric vector (integer vector or double equivalent)",
-    x = x
-  )
+    x = x)
 }
 
 #' @describeIn chk_whole_numeric Validate Whole Numeric
@@ -40,5 +39,8 @@ chk_whole_numeric <- function(x, x_name = NULL) {
 #' vld_whole_numeric(1.5)
 #' @export
 vld_whole_numeric <- function(x) {
-  is.integer(x) || (is.double(x) && vld_true(all.equal(x, as.integer(x))))
+  is.integer(x) || (is.double(x) &&
+                      vld_true(all.equal(x[!is.na(x)], trunc(x[!is.na(x)]))))
 }
+
+
