@@ -9,10 +9,11 @@ test_that("vld_character_or_factor", {
 })
 
 test_that("chk_character_or_factor", {
-  expect_null(chk_character_or_factor("1"))
+  expect_identical(chk_character_or_factor("1"), "1")
   expect_invisible(chk_character_or_factor("1"))
   expect_chk_error(
     chk_character_or_factor(TRUE),
     "^`TRUE` must be character or factor[.]$"
   )
 })
+
