@@ -8,10 +8,11 @@ test_that("vld_dbl", {
 })
 
 test_that("chk_dbl", {
-  expect_null(chk_dbl(1))
+  expect_identical(chk_dbl(1), 1)
   expect_invisible(chk_dbl(1))
   expect_chk_error(
     chk_dbl(TRUE),
     "^`TRUE` must be double [(]real[)] scalar[.]$"
   )
 })
+
