@@ -8,10 +8,11 @@ test_that("vld_integer", {
 })
 
 test_that("chk_integer", {
-  expect_null(chk_integer(1L))
+  expect_identical(chk_integer(1L), 1L)
   expect_invisible(chk_integer(1L))
   expect_chk_error(
     chk_integer(TRUE),
     "^`TRUE` must be integer[.]$"
   )
 })
+
