@@ -33,7 +33,8 @@ test_that("vld_join with missing values", {
 })
 
 test_that("chk_join", {
-  expect_null(chk_join(data.frame(z = 1), data.frame(z = 1), by = "z"))
+  expect_identical(chk_join(data.frame(z = 1), data.frame(z = 1), by = "z"),
+                   chk_join(data.frame(z = 1), data.frame(z = 1), by = "z"))
   expect_invisible(chk_join(data.frame(z = 1), data.frame(z = 1), by = "z"))
 
 })
@@ -45,3 +46,4 @@ test_that("chk_join", {
   )
 })
 
+
