@@ -1,5 +1,3 @@
-context("chk-matrix")
-
 test_that("vld_matrix", {
   expect_false(vld_matrix(1))
   expect_false(vld_matrix(array(1)))
@@ -8,11 +6,12 @@ test_that("vld_matrix", {
   expect_true(vld_matrix(matrix(1)))
 })
 
-test_that("vld_matrix", {
-  expect_null(chk_matrix(matrix(1)))
+test_that("chk_matrix", {
+  expect_identical(chk_matrix(matrix(1)), matrix(1))
   expect_invisible(chk_matrix(matrix(1)))
   expect_chk_error(
     chk_matrix(1),
     "^`1` must be an matrix[.]$"
   )
 })
+
