@@ -1,5 +1,3 @@
-context("chk-number")
-
 test_that("vld_number", {
   expect_false(vld_number(numeric(0)))
   expect_false(vld_number(NA_integer_))
@@ -13,20 +11,23 @@ test_that("vld_number", {
 })
 
 test_that("chk_number", {
-  expect_null(chk_number(1))
+  expect_identical(chk_number(1), 1)
   expect_invisible(chk_number(1))
   expect_chk_error(chk_number(TRUE), "^`TRUE` must be a number [(]non-missing numeric scalar[)][.]$")
   expect_chk_error(chk_number(TRUE, x_name = 1L), "^1 must be a number [(]non-missing numeric scalar[)][.]$")
 })
 
+
 test_that("vld_whole_number", {
   expect_chk_error(chk_whole_number(1.1), "^`1.1` must be a whole number [(]non-missing integer scalar or double equivalent[)][.]$")
   expect_chk_error(chk_whole_number(1.1, x_name = 1L), "^1 must be a whole number [(]non-missing integer scalar or double equivalent[)][.]$")
 })
 
 test_that("chk_whole_number", {
-  expect_null(chk_whole_number(1))
+  expect_identical(chk_whole_number(1), 1)
   expect_invisible(chk_whole_number(1))
   expect_chk_error(chk_whole_number(1.1), "^`1.1` must be a whole number [(]non-missing integer scalar or double equivalent[)][.]$")
   expect_chk_error(chk_whole_number(1.1, x_name = 1L), "^1 must be a whole number [(]non-missing integer scalar or double equivalent[)][.]$")
 })
+
+
