@@ -1,5 +1,3 @@
-context("chk-sorted")
-
 test_that("vld_sorted", {
   expect_true(vld_sorted(TRUE))
   expect_true(vld_sorted(1))
@@ -10,9 +8,11 @@ test_that("vld_sorted", {
 })
 
 test_that("chk_sorted", {
-  expect_null(chk_sorted(TRUE))
+  expect_identical(chk_sorted(TRUE), TRUE)
   expect_invisible(chk_sorted(TRUE))
-  expect_null(chk_sorted(c(x = TRUE)))
+  expect_identical(chk_sorted(c(x = TRUE)), c(x = TRUE))
 
   expect_chk_error(chk_sorted(2:1), "^`2:1` must be sorted[.]$")
 })
+
+
