@@ -1,5 +1,3 @@
-context("chk-string")
-
 test_that("vld_string", {
   expect_false(vld_string(character(0)))
   expect_false(vld_string(NA_character_))
@@ -9,7 +7,7 @@ test_that("vld_string", {
 })
 
 test_that("chk_string", {
-  expect_null(chk_string(""))
+  expect_identical(chk_string(""), "")
   expect_invisible(chk_string(""))
   expect_chk_error(chk_string(1), "^`1` must be a string [(]non-missing character scalar[)][.]$")
   expect_chk_error(chk_string(1, x_name = "''"), "^'' must be a string [(]non-missing character scalar[)][.]$")
@@ -26,7 +24,7 @@ test_that("vld_match", {
 })
 
 test_that("chk_match", {
-  expect_null(chk_match("1"))
+  expect_identical(chk_match("1"), "1")
   expect_invisible(chk_match("1"))
   expect_chk_error(chk_match(""), "^`\"\"` must match regular expression '.+'[.]$")
   expect_chk_error(
@@ -38,3 +36,4 @@ test_that("chk_match", {
     "`c[(]\"a\", \"b\"[)]` must have values matching regular expression 'b'[.]$"
   )
 })
+
